import assert from 'assert';
import { positionToString } from './formatters.mjs';

describe('Formatters unit tests', function () {
    describe('positionToString', function () {
        it('should convert position to sql view with null fom', function () {
            const position = {
                tk_uid: '86WHPRnKRdixKaKlkuunsA',
                ts: '2021-12-13 11:28:22.607',
                data: {
                    mac: '000000000031',
                    x: 26000,
                    y: 13420,
                    z: 1000,
                    sl_uid: 'f_byrlKIQ5_yeBoT9reKyg',
                    type: 'UWB',
                    fom: null
                }
            };
            const sqlPos = positionToString(position);
            const result = '("86WHPRnKRdixKaKlkuunsA","000000000031","2021-12-13 11:28:22.607",26000,13420,1000,"f_byrlKIQ5_yeBoT9reKyg","UWB",NULL)';
            assert(result === sqlPos, `${sqlPos} !== ${result}`);
        });
        it('should convert position to sql view with empty sl_uid', function () {
            const position = {
                tk_uid: '86WHPRnKRdixKaKlkuunsA',
                ts: '2021-12-13 11:28:22.607',
                data: {
                    mac: '000000000031',
                    x: 26000,
                    y: 13420,
                    z: 1000,
                    sl_uid: '',
                    type: 'UWB',
                    fom: null
                }
            };
            const sqlPos = positionToString(position);
            const result = '("86WHPRnKRdixKaKlkuunsA","000000000031","2021-12-13 11:28:22.607",26000,13420,1000, ,"UWB",NULL)';
            assert(result === sqlPos, `${sqlPos} !== ${result}`);
        });
        it('should convert position to sql view with 0 x,y,z', function () {
            const position = {
                tk_uid: '86WHPRnKRdixKaKlkuunsA',
                ts: '2021-12-13 11:28:22.607',
                data: {
                    mac: '000000000031',
                    x: 0,
                    y: 0,
                    z: 0,
                    sl_uid: '',
                    type: 'UWB',
                    fom: null
                }
            };
            const sqlPos = positionToString(position);
            const result = '("86WHPRnKRdixKaKlkuunsA","000000000031","2021-12-13 11:28:22.607",0,0,0, ,"UWB",NULL)';
            assert(result === sqlPos, `${sqlPos} !== ${result}`);
        });
        it('should convert position to sql view with undefined x,y,z', function () {
            const position = {
                tk_uid: '86WHPRnKRdixKaKlkuunsA',
                ts: '2021-12-13 11:28:22.607',
                data: {
                    mac: '000000000031',
                    x: undefined,
                    y: undefined,
                    z: undefined,
                    sl_uid: '',
                    type: 'UWB',
                    fom: null
                }
            };
            const sqlPos = positionToString(position);
            const result = '("86WHPRnKRdixKaKlkuunsA","000000000031","2021-12-13 11:28:22.607",NULL,NULL,NULL, ,"UWB",NULL)';
            assert(result === sqlPos, `${sqlPos} !== ${result}`);
        });
    })
});
