#!/usr/bin/env bash
set -x #echo on

PROJECT=rtls-solution-positions-manager

RPM_DESCRIPTION="Redpoint Positioning RTLS Solution Positions Manager"
RPM_MAINTAINER=help@redpointpositioning.com
RPP_VENDOR="Redpoint Positioning, Inc."

PROJECT_HOME=${WORKSPACE}

export PATH=/usr/local/bin:/usr/local/rbenv/shims:$PATH

VERSION="$( apps/positions-manager/sys-services/rtls-get-version.sh )"
RELEASE="$( apps/positions-manager/sys-services/rtls-get-release.sh )"
FILE="$( apps/positions-manager/sys-services/rtls-get-file-name.sh )"

echo "PROJECT_HOME:       ${PROJECT_HOME}"
echo "BUILDING ON BRANCH: ${BRANCH_NAME}"
echo "VERSION:            ${VERSION}"
echo "RELEASE:            ${RELEASE}"
echo "FILE:               ${FILE}"

rm -f "${PROJECT_HOME}"/*.deb
rm -f "${PROJECT_HOME}"/*.rpm
[ -d "${PROJECT_HOME}"/releases ] && rm -f "${PROJECT_HOME}"/releases/*

fpm -s dir -t deb -f \
	--description "${RPM_DESCRIPTION}" \
	--maintainer  "${RPM_MAINTAINER}" \
	--vendor "${RPP_VENDOR}" \
	--license "Proprietary" \
	--provides "rtls-solution-positions-manager" \
	--exclude ".git" \
	--prefix /usr/rtls/rtls-solution-positions-manager \
	--rpm-use-file-permissions --rpm-user rtls --rpm-group rtls \
	--before-remove apps/positions-manager/sys-services/pre-uninstall.sh \
	--before-install apps/positions-manager/sys-services/pre-install.sh \
	--after-install apps/positions-manager/sys-services/post-install.sh \
	--before-upgrade apps/positions-manager/sys-services/pre-update.sh \
	--after-upgrade apps/positions-manager/sys-services/post-update.sh \
	--post-uninstall apps/positions-manager/sys-services/post-uninstall.sh \
	--depends "nodejs (>= 20.5.1)" \
	--deb-group rtls \
  --deb-user rtls \
  --name "${PROJECT}" \
	--version "${VERSION}" \
	--iteration "${RELEASE}" \
	--package "${PROJECT_HOME}" \
	.
