import { WebSocketServer } from 'ws';
import Router from './router.mjs';
import logger from '../logger.mjs';
import { generateUid } from '../../utils/index.mjs';

let service = null;
const CONNECT_ATTEMPTS = 10;
let connectionAttempt = 0;

export function startServer({ wsPort }) {
    service = startService({ wsPort });
}

export async function stopServer() {
    if (!service) return;

    service.close();
    logger.info('WS Service stopped');
}

function heartbeat() {
    this.isAlive = true;
}

function startService({ wsPort }) {
    try {
        const wss = new WebSocketServer({ port: wsPort });
        logger.info(`WS listening on ${wsPort}`);

        wss.on('connection', function connection(ws) {
            ws.isAlive = true;
            ws.uid = generateUid();
            ws.on('pong', heartbeat)

            ws.on('message', function incoming(message) {
                Router(message.toString(), ws);
            });
        });

        const interval = setInterval(function ping() {
            wss.clients.forEach(function each(ws) {
                if (ws.isAlive === false) return ws.terminate();

                ws.isAlive = false;
                ws.ping();
            });
        }, 30000);

        wss.on('close', function close() {
            clearInterval(interval);
        });

        return wss;
    } catch (err) {
        logger.error('WS Service try connect to: ', wsPort);
        logger.error('WS Service connection', err);
        if (connectionAttempt <= CONNECT_ATTEMPTS) {
            connectionAttempt += 1;
            setTimeout(function () {
                startService({ wsPort });
            }, 5000 * connectionAttempt);
        } else {
            logger.info(`Stop trying connect to WS after ${connectionAttempt} attempts`);
        }
    }
}
