import * as zmq from 'zeromq/v5-compat.js';
import { APP_ZMQ_LISTEN_CHANNELS } from '../../system/index.mjs';
import Router from './router.mjs';
import logger from '../logger.mjs';

let service = null;
const CONNECT_ATTEMPTS = 10;
let connectionAttempt = 0;

export function stopServer() {
    if (service) {
        service.close();
    }
    logger.info('ZMQ Service stopped');
}

function subscribeService(service) {
    APP_ZMQ_LISTEN_CHANNELS.forEach(channel => {
        service.subscribe(channel);
    })
}

export function startService({ pubSubUrl }) {
    try {
        service = zmq.socket('sub');
        service.connect(pubSubUrl);
        subscribeService(service);

        logger.info('ZMQ Service SUB to: ', pubSubUrl);
        service.on('message', Router);

        service.on('offline', () => {
            logger.warn('ZMQ Client Offline');
        });

        service.on('error', (error) => {
            logger.error('ZMQ Service Error', error);
        });
    } catch (err) {
        logger.error('ZMQ Service try connect to: ', pubSubUrl);
        logger.error('ZMQ Service connection', err);
        if (connectionAttempt <= CONNECT_ATTEMPTS) {
            connectionAttempt += 1;
            setTimeout(function () {
                startService({ pubSubUrl });
            }, 5000 * connectionAttempt);
        } else {
            logger.info(`Stop trying connect to ZMQ after ${connectionAttempt} attempts`);
        }
    }
}
