import WebSocket from 'ws';
import { ClientBase } from './ClientBase.mjs';
import { CLIENT_TYPES } from './types.mjs';

export class WsClient extends ClientBase {
    /**
     * @typedef {Class} WsClient
     * @method send
     * @method close
     */

    /**
     * @property {Object}
     */
    client = null;

    /**
     * @property {String}
     */
    uid = null;

    /**
     * @param {Object} client - WebSocket client
     * @param {string} email - users email
     * @param {string} uid - client unique identifier
     */
    constructor(client, email, uid) {
        super(CLIENT_TYPES.WS, email);
        this.client = client;
        this.uid = uid;
        this.client.on('close', () => {
            this.onClose(email, uid);
        });
    }

    /**
     * @method
     * @param {string} message - message to send
     * @returns {undefined}
     */
    send(message) {
        if (this.client.readyState === WebSocket.OPEN) {
            this.client.send(message);
        }
    }

    /**
     * @method
     * @returns {undefined}
     */
    close() {
        if (this.client) {
            this.client.close();
        }
    }
}
