import assert from 'assert';
import { generateUid } from '../../utils/index.mjs';
import { WsClient } from './WsClient.mjs';


const client = {
    listeners: {
        'on': null
    },
    on: function (type, callback = () => {}) {
        this.listeners[type] = callback
    },
    close: function () {
        const callback = this.listeners['close'];
        callback();
    },
    send: function () {},
    readyState: 'OPEN'
}

describe('WsClient', function () {
    it('should init with type/email', async function() {
        const email = 'test@test.com';
        const uid = generateUid();
        const wsClient = new WsClient(client, email, uid);
        console.log(wsClient);
        assert(wsClient.type === 'websocket', `type not equal to ws`);
        assert(wsClient.email === email, `emails not equal`);
        assert(wsClient.uid === uid, `uids not equal`);
    });
    it('should implement setOnClose method', async function() {
        const email = 'test@test.com';
        const uid = generateUid();
        let counter = 0;
        const wsClient = new WsClient(client, email, uid);
        const onClose = () => { counter += 1; }
        wsClient.setOnClose(onClose);
        assert(counter === 0, `counter not equal to 0`);
        wsClient.onClose();
        assert(counter === 1, `counter was not incremented`);
    });
    it('should call onClose when invoke ws client close method', async function() {
        const email = 'test@test.com';
        const uid = generateUid();
        let counter = 0;
        const wsClient = new WsClient(client, email, uid);
        const onClose = (_email, _uid) => {
            assert(_email === email, 'emails not equal')
            assert(_uid === uid, 'emails not equal')
            counter += 1;
        }
        wsClient.setOnClose(onClose);
        wsClient.close();
        assert(counter === 1, `counter was not incremented`);
    });
});
