import assert from 'assert';
import { generateUid } from '../../utils/index.mjs';
import { State } from './State.mjs';
import ModelBase from '../ModelBase.mjs';

const projectUid = generateUid();
const companyUid = generateUid();
const repository = {
    state: {
        read: async function (mac) {
            return { mac, projectUid, companyUid }
        },
        save: async function ({ mac, projectUid, companyUid }) {
            return { mac, projectUid, companyUid }
        },
        remove: async function (mac) {
            return mac
        }
    }
}

describe('State', function () {
    before(function () {
        ModelBase.setRepository(repository);
    })

    it('should save node project', async function() {
        const mac = '00000000001a';
        const projectUid = generateUid();
        const companyUid = generateUid();
        const data = { mac, projectUid, companyUid };
        const result = await new State().saveNodeProject(data);
        assert.deepStrictEqual(result, data);
    });

    it('should remove node project', async function() {
        const mac = '00000000001a';
        const result = await new State().removeNodeProject({ mac });
        assert.strictEqual(result, mac);
    });

    it('should read node project', async function() {
        const mac = '00000000001a';
        const result = await new State().readNodeProject(mac);
        assert.deepStrictEqual(result, { mac: mac.toUpperCase(), projectUid, companyUid });
    });
});
