import UseCaseBase from '../UseCaseBase.mjs';
import { User, AuthenticationError } from '../../models/index.mjs';
import { verifyToken } from '../../utils/index.mjs';

export class SessionCheck extends UseCaseBase {
    static validationRules = {
        token: ['required', 'string'],
        email: ['required', 'string']
    };

    async execute(params) {
        const decodedData = await verifyToken(params.token);
        if (!decodedData || !decodedData.user || decodedData.user.email !== params.email) {
            throw new AuthenticationError('WRONG_USER_EMAIL');
        }
        const user = await new User().read(params.email);

        if (!user) throw new AuthenticationError('USER_NOT_ACTIVE');

        return decodedData;
    }
}
