import UseCaseBase from '../UseCaseBase.mjs';
import { Dispatcher, Notify } from '../../models/index.mjs';

export class SolutionZoneEventHandle extends UseCaseBase {
    /**
     * @method
     * @param {Object} zoneEventRaw - raw zone event
     * @param {String} zoneEventRaw.action - zone event action (enter, leave)
     * @param {Number} zoneEventRaw.ts - unix timestamp
     * @param {Number} zoneEventRaw.ms - millisecond part of te timestamp
     * @param {String} zoneEventRaw.obj_uid - trackable object uid
     * @param {String} zoneEventRaw.project_uid - project uid
     * @param {String} zoneEventRaw.sublocation_uid - sublocation uid
     * @param {Number} zoneEventRaw.x - zone event X coordinate
     * @param {Number} zoneEventRaw.y - zone event Y coordinate
     * @param {Number} zoneEventRaw.z - zone event Z coordinate
     * @param {String} zoneEventRaw.zone_type_name - zone type
     * @param {String} zoneEventRaw.zone_uid - zone unique identifier
     * @returns {Promise<null>}
     */
    async execute(zoneEventRaw) {
        const { topic, message } = Notify.getZoneEventMessage(zoneEventRaw);
        await Dispatcher.send(topic, message);
        return null;
    }
}
