import { Dispatcher, Notify, StateManager } from '../../models/index.mjs';
import UseCaseBase from '../UseCaseBase.mjs';

export class NotifyHandle extends UseCaseBase {
    /**
     * @class {NotifyHandle}
     * */

    /**
     * @method
     * @param {Object} notifyRaw - notify channel message
     * @param {Number} notifyRaw.ts - unix timestamp
     * @param {Number} notifyRaw.ms - milliseconds part of the timestamp
     * @param {String|undefined} notifyRaw.project_uid - project unique identifier
     * @param {String|undefined} notifyRaw.company_uid - company unique identifier
     * @param {String} notifyRaw.mac - device mac address
     * @param {String} notifyRaw.object - entity name
     * @param {String} notifyRaw.action - action name
     * @param {Object} notifyRaw.plist - payload
     * @return {null}
     */
    async execute(notifyRaw) {
        await StateManager.handleNotifyMessage(notifyRaw);
        const { topic, message } = await Notify.getNotifyMessage(notifyRaw);
        await Dispatcher.send(topic, message);

        return null;
    }
}
