import RepoBase from '../RepoBase.mjs';

export class StateRepository extends RepoBase {
    /**
     * @typedef {Class} StateRepository
     */

    /**
     * @param {Object} options - repository options
     * @param {Object} options.redis - redis connection
     * @param {Object} options.mariadb - mariadb connection
     * @param {Object} options.prefix - redis storage prefix
     */
    constructor(options) {
        const { prefix, redis, mariadb } = options;

        super(mariadb, redis, `${prefix}:state`);
    }

    /**
     * @method
     * @param {string} mac - hardware MAC address
     * @param {string} projectUid - project unique identifier
     * @param {string} companyUid - company unique identifier
     * @return {Promise<Object>} returns data saved in DB
     */
    async save({ mac, projectUid, companyUid}) {
        const fields = ['projectUid', projectUid, 'companyUid', companyUid];
        await this.redis.hmset(`${this.document}:mac:${(mac || '').toUpperCase()}`, ...fields);

        return { mac, projectUid };
    }

    /**
     * @method
     * @param {String} mac - hardware MAC address
     * @return {Promise<String>} returns result of key removing
     */
    async remove(mac) {
        await this.redis.del(`${this.document}:mac:${(mac || '').toUpperCase()}`);

        return mac;
    }

    /**
     * @method
     * @param {String} mac - hardware MAC address
     * @return {Promise<Object>} returns result of key removing
     */
    async read(mac) {
        return  this.redis.hgetall(`${this.document}:mac:${(mac || '').toUpperCase()}`);
    }

    /**
     * @method
     * @return {Promise<Array<Object>>} returns all mac-project associations
     */
    async clear() {
        return  this.redis.delwild(`${this.document}:mac:*`);
    }
}
