import RepoBase from '../RepoBase.mjs';
import { RepoError } from '../models/index.mjs';

export class UserRepository extends RepoBase {
    /**
     * @typedef {Class} UserRepository
     */

    /**
     * @param {Object} options - repository options
     * @param {Object} options.redis - redis connection
     * @param {Object} options.mariadb - mariadb connection
     * @param {string} options.prefix - redis storage prefix
     */
    constructor(options) {
        const { redis, mariadb, prefix } = options;

        super(mariadb, redis, prefix);
    }

    /**
     * @method
     * @param {string} email - users email
     * @return {Promise<Object>} returns data saved in DB
     */
    async read({ email }) {
        const result = await this.mariadb.queryAsync('SELECT * FROM users WHERE email = ?', [email]).catch((err) => {
            throw new RepoError(err);
        });
        return result[0];
    }
}
